xsdata.codegen.handlers.attribute\_mismatch module
==================================================

.. automodule:: xsdata.codegen.handlers.attribute_mismatch
   :members:
   :undoc-members:
   :show-inheritance:
